@@ -35,3 +35,13 @@ class UserNode(DjangoObjectType):
 class UserQuery(graphene.ObjectType):
     user = graphene.relay.Node.Field(UserNode)
     users = DjangoFilterConnectionField(UserNode)
+
+
+class MeQuery(graphene.ObjectType):
+    me = graphene.Field(UserNode)
+
+    def resolve_me(self, info):
+        user = info.context.user
+        if user.is_authenticated:
+            return user
+        return None
